@@ -22,7 +22,6 @@ from pytensor.tensor.basic import (
 )
 from pytensor.tensor.exceptions import NotScalarConstantError
 from pytensor.tensor.shape import Shape_i
-from pytensor.tensor.sort import SortOp
 
 
 ARANGE_CONCRETE_VALUE_ERROR = """JAX requires the arguments of `jax.numpy.arange`
@@ -201,16 +200,9 @@ def jax_funcify_Tri(op, node, **kwargs):
     def tri(*args):
         # args is N, M, k
         args = [
-            x if const_x is None else const_x for x, const_x in zip(args, const_args)
+            x if const_x is None else const_x
+            for x, const_x in zip(args, const_args, strict=True)
         ]
         return jnp.tri(*args, dtype=op.dtype)
 
     return tri
-
-
-@jax_funcify.register(SortOp)
-def jax_funcify_Sort(op, **kwargs):
-    def sort(arr, axis):
-        return jnp.sort(arr, axis=axis)
-
-    return sort
