@@ -107,7 +107,7 @@ class RandomGeneratorType(RandomType[np.random.Generator]):
         return _eq(sa, sb)
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def __hash__(self):
         return hash(type(self))
