@@ -425,7 +425,7 @@ class SpecifyShape(COp):
             )
 
         type_shape = [None] * x.ndim
-        for i, (xts, s) in enumerate(zip(x.type.shape, shape)):
+        for i, (xts, s) in enumerate(zip(x.type.shape, shape, strict=True)):
             if xts is not None:
                 type_shape[i] = xts
             else:
@@ -448,7 +448,10 @@ class SpecifyShape(COp):
             raise AssertionError(
                 f"SpecifyShape: Got {x.ndim} dimensions (shape {x.shape}), expected {ndim} dimensions with shape {tuple(shape)}."
             )
-        if not all(xs == s for xs, s in zip(x.shape, shape) if s is not None):
+        # strict=False because we are in a hot loop
+        if not all(
+            xs == s for xs, s in zip(x.shape, shape, strict=False) if s is not None
+        ):
             raise AssertionError(
                 f"SpecifyShape: Got shape {x.shape}, expected {tuple(int(s) if s is not None else None for s in shape)}."
             )
@@ -512,7 +515,9 @@ class SpecifyShape(COp):
             """
         )
 
-        for i, (shp_name, shp) in enumerate(zip(shape_names, node.inputs[1:])):
+        for i, (shp_name, shp) in enumerate(
+            zip(shape_names, node.inputs[1:], strict=True)
+        ):
             if NoneConst.equals(shp):
                 continue
             code += dedent(
@@ -575,8 +580,9 @@ def specify_shape(
     # The above is a type error in Python 3.9 but not 3.12.
     # Thus we need to ignore unused-ignore on 3.12.
     new_shape_info = any(
-        s != xts for (s, xts) in zip(shape, x.type.shape) if s is not None
+        s != xts for (s, xts) in zip(shape, x.type.shape, strict=False) if s is not None
     )
+
     # If shape does not match x.ndim, we rely on the `Op` to raise a ValueError
     if not new_shape_info and len(shape) == x.type.ndim:
         return x
